Command Line Interface
======================
zenodo_client automatically installs the command :code:`zenodo_client`. See
:code:`zenodo_client --help` for usage details.

.. click:: zenodo_client.cli:main
   :prog: zenodo_client
   :show-nested:
